class rob:
    def scared():
        lol = "Rob (the dev of the api) is scared that i will upload this module"
        return lol
    def hot():
        idkanymore = "Rob is veri hot and seggsy"
        return idkanymore